Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrefixMessage ¶ added in v0.9.3
PrefixMessage prefixes the given message with plugin information. The prefix is only applied if it is not already applied.
func Serve ¶
func Serve(pluginServer api.PluginServer, serviceServers ...api.ServiceServer)
func ServeOptions ¶ added in v0.9.3
func ServeOptions(options ...pluginoption.ServerOption) error
Types ¶
type Facade ¶ added in v0.9.3
Facade is embedded by plugin interface facade implementations as a convenient way to embed Info but also provide a set of convenient functions for embellishing and generating errors that have the plugin name prefixed.
func FixedFacade ¶ added in v0.9.3
FixedFacade is a helper that creates a facade from fixed information, i.e. not the product of a loaded plugin.
func (*Facade) Error ¶ added in v0.9.3
Error creates a gRPC status with the given code and message. The message will be prefixed with the plugin name.
func (*Facade) Errorf ¶ added in v0.9.3
Errorf creates a gRPC status with the given code and formatted message. The message will be prefixed with the plugin name.